# Readme
## Intrinsic Stacking domains in graphene on silicon carbide: a pathway for intercalation
Data used in the article De Jong, T. A., Krasovskii, E. E., Ott, C., Tromp, R. M., van der Molen, S. J., & Jobst, J., "Intrinsic stacking domains in graphene on silicon carbide: a pathway for intercalation." Phys. Rev. Materials (2018).

#### Corresponding Author:

Tobias A. de Jong

##### Contact Information:

jongt@physics.leidenuniv.nl  
Huygens-Kamerlingh Onnes Laboratorium  
Leiden University  
P.O. Box 9504  
NL-2300 RA Leiden  
The Netherlands  


### Introduction
This dataset contains a Low Energy Electron Microscopy (LEEM) bright field spectroscopic 
image series of a region of few layer graphene on Silicon Carbide, two inequivalent dark field 
spectroscopic image series of the same region, a bright field time series of the same region 
during deintercalation of the intercalated hydrogen and ab initio calculated dark field spectra,
as well as abstracted dark field spectra for bilayer and trilayer graphene for the same Dark 
Field geometry. 
The metadata of the measured datasets contains for each frame a time stamp, 
the pressure, the measured temperature, the electron landing energy and an overall multiplier 
for the intensity deduced from the variable detector gain.  
All data was acquired on the ESCHER LEEM facility at Leiden University.
Further relevant methods are described in the corresponding paper.  

### Data files
The dataset contains the following files:
* `README.md`: This readme.
* `G_SiC_BF.nc` netCDF4 file of the bright field spectrocopic LEEM image series.
* `G_SiC_DF2.nc` netCDF4 file of a dark field spectrocopic LEEM image series.
* `G_SiC_DF1.nc` netCDF4 file of the second, inequivalent dark field spectrocopic LEEM image series.
* `G_SiC_deintercalation.nc` netCDF4 file of the bright field deintercalation LEEM image time series.
* `G_SiC_BF_spectra.csv` Bright field spectra extracted from `G_SiC_BF.nc`.
* `G_SiC_DF_spectra.csv` Dark field spectra extracted from `G_SiC_DF2.nc` .
* `Graphene_calculated_(0,0)_spectra.csv` Ab initio calculated spectra of the (0,0) specular beam for tilted geometry. Not used in the paper, but included for completeness. 
As this is in tilted geometry, this is **not** equivalent to the extracted bright field spectra!
* `Graphene_calculated_(1,0)_spectra.csv` Ab initio calculated spectra of the (1,0) diffracted beam for tilted geometry. This is the beam in the direction of the tilt angle, opposite of the optical axis compared to the specular beam.
* `Graphene_calculated_(1,1)_spectra.csv` Ab initio calculated spectra of the (1,1)/(1,-1) diffracted beams for tilted geometry. This is data for the two first order beams on the axis through the optical axis perpendicular to the specular and (1,0) beam. Not used in the paper, but included for completeness.

All experimental details are discussed in the paper.
The image series were corrected for detector artefacts and image drift. Pixels outside the detector are zero-filled.

### Data format
#### netCDF4 files
The netCDF4 files each contain a `Intensity` variable containing the images, expressed in coordinates `time`, `x` and `y`.
In addition, various measured or set quantities are given as extra data variables, each with an attribute `units` if appropriate. The following quantities are present:
* `Pressure` Pressure measured in the sample room in millibar.
* `Multiplier` Multiplier used to scale the intensity from its real value to the stored value. Divide the stored Intensity by the multiplier to regain the original magnitude.
* `Energy` The measured landing energy or relative sample potential.
* `Energy_set` The set landing energy or relative sample potential.
* `Temperature` Temperature of the sample measured by pyrometer.
* `Objective` Objective lens current in Ampere.

#### csv files
The csv files are comma separated and each contain a single header row with column names, marked with a `#`. The first column corresponds to Landing Energy, 
each of the other columns is labeled, either `nL` for the number of layers in the bright field case
 or to its stacking, so `AB` or `AC` for the bilayer cases and `ABC`, `ABA`, `ACB` and `ACA` for the trilayer case.
 
### Example code

Using Python to grab an image from a spectroscopic dataset 
and to plot the Intensity as function of voltage for some area:

```python
import numpy as np
import matplotlib.pyplot as plt
import xarray as xr

opendap_location =  'https://opendap.tudelft.nl/thredds/dodsC/data2/uuid/a7ff07f4-0ac8-4778-bec9-636532cfcfc1/'

# Retrieve the metadata from the OPeNDAP server using xarray
dataset = xr.open_dataset(opendap_location + 'G_SiC_DF2.nc')

# Find the image closest to the landing energy 32.5 eV as shown in the paper.
E_32_5eV = np.argmin(np.abs(dataset['Energy'] - 32.5))

# Do some plotting
fig, axs = plt.subplots(ncols=2, figsize=[12,5])
# Show that particular image
axs[0].imshow(dataset['Intensity'][E_32_5eV].T, cmap='gray')

# Plot some IV's corresponding to AB and AC stacking
# Divide by the multiplier to obtain real intensities.
axs[1].semilogy(dataset['Energy'], 
                dataset['Intensity'][:, 1083, 442] / dataset['Multiplier'], 
                label='AB')
axs[1].semilogy(dataset['Energy'], 
                dataset['Intensity'][:, 945, 367] / dataset['Multiplier'], 
                label='AC')
axs[1].set_ylabel('Intensity')
axs[1].set_xlabel('Landing Energy')
axs[1].legend()
plt.show()
```

### Datasets use in Figures
Below is a list for each dataset which figures in de Jong et al. are abstracted from it.
* `G_SiC_BF.nc`: Fig 1(b), Fig 4(b,c) and SI Figure 1(a, b).
* `G_SiC_DF2.nc`: Fig 1(e), spectra in Fig 2(c, d) are extracted from this dataset, extracted spectra are also separately available in `G_SiC_DF_spectra.csv`. 
* `G_SiC_DF1.nc`i: Fig 1(h).
* `G_SiC_deintercalation.nc` Fig 4(a,b,e,f,g)
* `G_SiC_BF_spectra.csv`: Bright field spectra extracted from `G_SiC_BF.nc`, in SI Figure 1(a).
* `G_SiC_DF_spectra.csv`: Dark field spectra extracted from `G_SiC_DF2.nc`, in Fig 2(c,d).
* `Graphene_(1,0)_spectra.csv`: Fig 2(e,f)
